<?php

/**
 * @file
 * Contains \Drupal\drd\Command\DrdCommandLocalActionBase.
 */

namespace Drupal\drd\Command;

use Drupal\drd\Entity\DrdHost;
use Drupal\drd\Plugin\DrdActionLocalBase;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class DrdCommandLocalActionBase.
 *
 * @package Drupal\drd
 */
abstract class DrdCommandLocalActionBase extends DrdCommandActionBase {

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);

    if (empty($action) || !($action instanceof DrdActionLocalBase)) {
      $output->writeln('No valid local action!');
      return;
    }

    $host_id = $input->getOption('host-id');
    if ($host_id) {
      $hosts = [
        \Drupal::entityTypeManager()
          ->getStorage('drd_host')
          ->load($host_id)
      ];
    }
    else {
      $hosts = \Drupal::entityTypeManager()
        ->getStorage('drd_host')
        ->loadByProperties([
          'status' => 1,
        ]);
    }
    if (empty($hosts)) {
      $output->writeln('No host found!');
      return;
    }
    $output->writeln('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($hosts as $host) {
      /** @var DrdHost $host */
      $output->writeln('- on ' . $host->getName());
      if ($action->executeAction($host)) {
        $output->writeln('  ok!');
      }
      else {
        $output->writeln('  failure!');
      }
    }

    $output->writeln('Completed!');
  }

}
