<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DrdActionDomainsReceive.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DrdCore;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Plugin\DrdActionRemoteBase;
use Drupal\drd\Plugin\DrdActionRemoteCoreBase;

/**
 * Provides a 'DrdActionDomainsReceive' action.
 *
 * @Action(
 *  id = "drd_action_domains_receive",
 *  label = @Translation("Receive domains"),
 *  type = "drd_core",
 * )
 */
class DrdActionDomainsReceive extends DrdActionRemoteCoreBase {

  /**
   * @param DrdCore $core
   * @return bool
   */
  public function executeAction($core) {
    $response = parent::executeAction($core);
    if (!$response) {
      return FALSE;
    }

    /** @var DrdDomain $domain */
    $domain = $this->drdEntity;
    $crypt = $domain->get('crypt')->value;
    $crypt_setting = $domain->getCryptSetting();

    $newDomains = 0;
    foreach ($response as $shortname => $item) {
      $d = DrdDomain::instanceFromUrl($core, 'http://' . $item['uri'], []);
      if ($d->isNew()) {
        if ($d->ping()) {
          $d->remoteInfo();
        }
        else {
          // Leave name of domain empty such that we can see that it is not enabled yet.
          $d->initValues('', $crypt, $crypt_setting);
          $newDomains++;
        }
      }
      $d
        ->setAliase($item['aliase'])
        ->save();
    }
    if ($newDomains) {
      DrdActionRemoteBase::response('drd_action_domains_enableall', $core);
    }

    return TRUE;
  }

}
