<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\views\field\DomainNameViewField.
 */

namespace Drupal\drd\Plugin\views\field;

use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\drd\Entity\DrdDomain;
use Drupal\views\Plugin\views\field\Standard;
use Drupal\views\ResultRow;

/**
 * A handler to display the domain name.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("domain_name_view_field")
 */
class DomainNameViewField extends Standard {
  /**
   * @inheritDoc
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    $this->realField = 'name';
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    /** @var DrdDomain $domain */
    $domain = $values->_entity;
    $name = $domain->getName(FALSE);
    if (empty($name)) {
      $output = $this->t('Make sure you are %login remotely, then %enable DRD access.', [
        '%login' => $domain->getRemoteLoginLink($this->t('logged in')),
        '%enable' => $domain->getRemoteSetupLink($this->t('enable'), TRUE),
      ]);
    }
    else {
      $output = \Drupal::linkGenerator()->generate($name, new Url('entity.drd_domain.canonical', ['drd_domain' => $domain->id(),]));
    }
    return Markup::create('<div class="drd-domain-name">' . $output . '</div>');
  }

}
