<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\views\field\RemoteStatusViewField.
 */

namespace Drupal\drd\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\drd\DrdRemoteInterface;
use Drupal\drd\Entity\DrdDomain;
use Drupal\drd\Entity\DrdRequirement;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * Abstract class for field handlers that display status indicators for host,
 * core and domain.
 */
abstract class RemoteStatusViewField extends FieldPluginBase {
  /**
   * {@inheritdoc}
   */
  public function usesGroupBy() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // do nothing -- to override the parent query.
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['hide_alter_empty'] = array('default' => FALSE);
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    /** @var DrdRemoteInterface $remote */
    $remote = $values->_entity;
    if ($remote instanceof DrdDomain && !$remote->get('installed')->value) {
      return '';
    }

    $warnings = $this->getCategories($remote, 'warnings');
    $errors = $this->getCategories($remote, 'errors');

    $allCategories = DrdRequirement::getCategoryKeys();

    $output = '';
    foreach ($allCategories as $category) {
      $class = [$category];
      if (in_array($category, $errors)) {
        $class[] = 'error';
      }
      else if (in_array($category, $warnings)) {
        $class[] = 'warning';
      }
      else {
        $class[] = 'ok';
      }
      $output .= '<span title="' . $category . '" class="' . implode(' ', $class) . '">' . $category . '</span>';
    }
    return Markup::create('<div class="drd-remote-status">' . $output . '</div>');
  }

  /**
   * @param DrdRemoteInterface $remote
   * @return DrdDomain[]
   */
  abstract protected function getDomains($remote);

  /**
   * @param DrdRemoteInterface $remote
   * @param string $field
   * @return array
   */
  private function getCategories($remote, $field) {
    $ids = [];
    foreach ($this->getDomains($remote) as $domain) {
      foreach ($domain->get($field)->getValue() as $value) {
        $ids[] = $value['target_id'];
      }
    }

    if (empty($ids)) {
      return [];
    }

    $categories = \Drupal::database()->select('drd_requirement', 'r')
      ->fields('r', ['category'])
      ->distinct()
      ->condition('r.id', $ids, 'IN')
      ->execute()
      ->fetchAllKeyed(0, 0);
    return $categories;
  }
}
